summaryrefslogtreecommitdiffstats
path: root/kalzium/src/spectrum.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
commit0a6e0958c03e41c87b15557b6f407874f20c2f8d (patch)
tree2cdd58c4013b1be09cfcbb4ddae2b05712b9aeee /kalzium/src/spectrum.h
parent83f9dfafc157ff7823804b3ff457b43d021a5b4b (diff)
downloadtdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.tar.gz
tdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1157642 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalzium/src/spectrum.h')
-rw-r--r--kalzium/src/spectrum.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kalzium/src/spectrum.h b/kalzium/src/spectrum.h
index 7578973d..ca6bcdac 100644
--- a/kalzium/src/spectrum.h
+++ b/kalzium/src/spectrum.h
@@ -21,8 +21,8 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
class QPixmap;
class Element;
@@ -66,12 +66,12 @@ class Spectrum
///relative. The highest is per definition 1000
int intensity;
- QString electronconfig1;
- QString electronconfig2;
- QString term1;
- QString term2;
- QString J1;
- QString J2;
+ TQString electronconfig1;
+ TQString electronconfig2;
+ TQString term1;
+ TQString term2;
+ TQString J1;
+ TQString J2;
};
/**
@@ -103,9 +103,9 @@ class Spectrum
* @param min the lowest allowed wavalength in nanometer
* @param max the highest allowed wavalength in nanometer
*
* @return the wavelength in a QValueList<double>
*/
- QValueList<double> wavelengths( double min, double max );
+ TQValueList<double> wavelengths( double min, double max );
/**
* @return the smallest wavelength
@@ -124,7 +124,7 @@ class Spectrum
/**
* @return the list of bands of the spectrum
*/
- QValueList<band>* bandlist(){
+ TQValueList<band>* bandlist(){
return &m_bandlist;
}
@@ -140,7 +140,7 @@ class Spectrum
/**
* @return the data of a spectrum as HTML code
*/
- QString bandsAsHtml();
+ TQString bandsAsHtml();
/**
* @return the parent element of this spectrum
@@ -162,7 +162,7 @@ class Spectrum
/**
* the internal dataset
*/
- QValueList<band> m_bandlist;
+ TQValueList<band> m_bandlist;
/**
* the cached values of the highest and lowest wavelength
@@ -103,9 +103,9 @@ class Spectrum
* @param max the highest allowed wavalength in nanometer
*
- * @return the wavelength in a QValueList<double>
+ * @return the wavelength in a TQValueList<double>
*/